@@ -17,14 +17,14 @@ import org.gnu.glib.Handle;
  * Application settings such as theme, fonts, toolbar icon size and cursor blink
  * times. Most of these are set in the gtk theme or gnome control center and so
  * changing them within applications is discouraged.
- *
- * <p>These have not yet been implemented in Java-Gnome
+ * 
+ * <p>
+ * These have not yet been implemented in Java-Gnome
  */
-public class Settings extends GObject 
-{
+public class Settings extends GObject {
 
     public Settings() {
-        super( getType() );
+        super(getType());
     }
 
     /**
@@ -34,7 +34,7 @@ public class Settings extends GObject
         return new Type(gtk_settings_get_type());
     }
 
-    native static final protected int gtk_settings_get_type ();
-    native static final protected Handle gtk_settings_get_default ();
-}
+    native static final protected int gtk_settings_get_type();
 
+    native static final protected Handle gtk_settings_get_default();
+}
